@@ -96,7 +96,7 @@ class SingleConditionSearch:
 
         suffix = get_suffix_by_accuracy(accuracy)
         if suffix:
-            cmd = f'self.qs = Q({search_field}__{suffix}="{search_keywords}")'
+            cmd = f'self.qs = Q({search_field}__{suffix}="{search_keywords}")'      # isnull时应转为bool! 待完善.
         else:
             cmd = f'self.qs = Q({search_field}="{search_keywords}")'
 
