@@ -215,7 +215,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
             GET /api/index/BaseList/5/
     """
     
-    _name = 'BaseListView'
+    _name = 'BaseListView'      # 这个在自动生成wiki时要用到
     
     renderer_classes = (StateMsgResultJSONRenderer,)
 
@@ -225,6 +225,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
     order_type_ls = []
     distinct_field_ls = []
+    only_get_distinct_field = False     # 仅返回distinct指定的字段
 
     serializer_class = None
     auto_generate_serializer_class = False
@@ -301,17 +302,41 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
     def get_serializer_class(self):
         if self.method == 'retrieve':
-            self.serializer_class = self.retrieve_serializer_class or self.serializer_class
+            ret = self.retrieve_serializer_class or self.serializer_class
         elif self.method == 'list':
-            self.serializer_class = self.list_serializer_class or self.serializer_class
+            ret = self.list_serializer_class or self.serializer_class
         else:
-            self.serializer_class = self.retrieve_serializer_class or self.serializer_class or self.list_serializer_class
+            ret = self.retrieve_serializer_class or self.serializer_class or self.list_serializer_class
 
         if self.auto_generate_serializer_class and self.serializer_class is None:
-            self.serializer_class = get_base_serializer(self.queryset, base_fields=self.base_fields)
+            ret = get_base_serializer(self.queryset, base_fields=self.get_base_fields())
 
-        assert self.serializer_class, '属性serializer_class不能为空!'
-        return self.serializer_class
+        # --- 仅获取distinct之后的字段
+        only_get_distinct_field = self.get_only_get_distinct_field()
+        if only_get_distinct_field:
+            distinct_field_ls = self.get_distinct_field_ls()
+            assert distinct_field_ls, '指定了only_get_distinct_field的同时必须指定distinct_field_ls!'
+            ret = get_base_serializer(self.queryset, distinct_field_ls)
+            return ret
+
+        assert ret, '返回的serializer_class不能为空!'
+        return ret
+
+    def get_only_get_distinct_field(self):
+        query_dc = self.get_request_data()
+        key = 'only_get_distinct_field'
+        value = query_dc.get(key)
+        only_get_distinct_field = pure.convert_query_parameter_to_bool(value) if value else self.only_get_distinct_field
+        return only_get_distinct_field
+
+    def get_distinct_field_ls(self):
+        query_dc = self.get_request_data()
+        distinct_field_ls = get_list(query_dc, 'distinct_field_ls')
+        distinct_field_ls = distinct_field_ls if distinct_field_ls else self.distinct_field_ls
+        return distinct_field_ls
+
+    def get_base_fields(self):
+        return self.base_fields
 
     def get_retrieve_ret(self, request: Request, *args, **kwargs):
         """
@@ -460,6 +485,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
             meta = base_model.objects.first()._meta
             field_names = [field.name for field in meta.fields]
+            field_names.append('pk')    # 将主键pk加进去作为过滤条件
             if self.queryset.count():
                 qs_i = self.queryset[0]
                 # 可能用annotate增加了注释字段, 所以要处理一下, 避免过滤出错
@@ -467,7 +493,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
                     field_names = list(qs_i.keys())
 
             for fn in field_names:      # fn: field_name
-                if FILTER_ALL_FIELDS or fn in self.filter_fields:
+                if FILTER_ALL_FIELDS or fn in self.filter_fields or fn == 'pk':
                     if fn in query_dc:
                         value = query_dc.get(fn)
                         if value is not None and value != '':       # 默认为空字符串时, 将不作为过滤条件
@@ -903,6 +929,10 @@ class DecoratorBaseListView(BaseListView):
     def get(self, request, *args, **kwargs):
         return super().get(*args, **kwargs)
 
+    @api_decorator
+    def post(self, request, *args, **kwargs):
+        return super().post(*args, **kwargs)
+
 
 class DecoratorCompleteModelView(CompleteModelView):
     """
