@@ -9,6 +9,7 @@ import pandas as pd
 def version():
     """
     * 2021/2/22
+    - [pypi_url](https://pypi.org/project/bddjango/)
 
     # 党史项目结束, 海南项目开始
 
@@ -16,7 +17,7 @@ def version():
         - 修复了AdvancedSearchView post时page_size失效的问题
         - 对`list`的数据返回格式进行了优化, 避免了自定义page_size时无效的bug
         - `BaseListView`增加`set_request_data`方法
-        - 优化`distince_type_ls`和o`rder_type_ls`的错误提示
+        - 优化`distince_type_ls`和`order_type_ls`的错误提示
         - `AdvancedSearchView`增加`Q_add_ls`检索方法
         - `.pure`增加`convert_query_parameter_to_bool`函数
         - '.django'增加`update_none_to_zero_by_field_name`函数
@@ -27,7 +28,7 @@ def version():
         - template调整`simpleui_change_list_actions.html`样式
         - 新增`only_get_distinct_field`功能
     """
-    v = "2.1.6"     # 正式版: 2.1.5
+    v = "2.1.7"     # 正式版: 2.1.6
     return v
 
 
